<?php
/**
 * Blogged Pro: Color Patterns
 *
 * @package WordPress
 * @subpackage Blogged Pro
 * @since 1.0
 */

/**
 * Generate the CSS for the current custom color scheme.
 */
function blogged_pro_custom_colors_css() {
  	$options= blogged_pro_get_theme_options();

	$color_value = $options['colorscheme_hue'];
	
	$css = '
	/*--------------------------------------------------------------
	# Background Color
	--------------------------------------------------------------*/
	#site-navigation,
	.backtotop,
	.archive-blog-wrapper article .entry-container a.btn:hover,
	#featured-post article:first-child .entry-container a.btn:hover,
	#respond input[type="submit"],
	.pagination .page-numbers.current,
	.pagination .page-numbers:hover,
	.pagination .page-numbers:focus,
	.widget_search form.search-form .search-submit:hover,
	.widget_search form.search-form .search-submit:focus,
	input[type="submit"],
	.jetpack_subscription_widget input[type="submit"],
	.jetpack_subscription_widget input[type="submit"]:hover,
	.jetpack_subscription_widget input[type="submit"]:focus,
	#secondary .jetpack_subscription_widget input[type="submit"]:hover,
	#secondary .jetpack_subscription_widget input[type="submit"]:focus,
	.reply a,
	.btn,
	.blog-posts .entry-meta:before {
	    background-color: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Text Color
	--------------------------------------------------------------*/
	.main-navigation ul#primary-menu li.current-menu-item > a,
	.main-navigation ul#primary-menu li:hover > a,
	#latest-post h2.section-title, 
	#latest-post .post-categories li a, 
	#latest-post .entry-container .entry-title a:hover, 
	#latest-post .posted-on a:hover,
	#latest-post h2.section-title, 
	#latest-post .post-categories li a, 
	#latest-post .entry-container .entry-title a:hover, 
	#latest-post .posted-on a:hover,
	#must-read h2.section-title, 
	#must-read .post-categories li a, 
	#must-read .entry-container .entry-title a:hover, 
	#must-read .posted-on a:hover, 
	#must-read .entry-content a:hover,
	#featured-post article:first-child ul.post-categories a,
	.education-wrapper .entry-title a:hover, 
	#featured-post article .entry-container ul.post-categories a,
	#featured-post .byline a:hover, 
	#featured-post .posted-on a:hover,
	#featured-post article:first-child .entry-container a.btn,
	.archive-blog-wrapper h2.section-title, 
	.archive-blog-wrapper .post-categories li a, 
	.archive-blog-wrapper article.has-post-thumbnail .entry-title a:hover,
	.archive-blog-wrapper article.no-post-thumbnail .entry-title a:hover, 
	.archive-blog-wrapper .byline a:hover, 
	.archive-blog-wrapper .posted-on a:hover,
	.archive-blog-wrapper article .entry-container a.btn,
	.post-categories a:hover, .post-categories a:focus,
	.post-navigation a:hover, 
	.posts-navigation a:hover,
	.post-navigation a:focus, 
	.posts-navigation a:focus,
	.widget_popular_post h3 a:hover,
	.widget_popular_post h3 a:focus,
	.widget_popular_post a:hover time,
	.widget_popular_post a:focus time,
	.widget_latest_post h3 a:hover,
	.widget_latest_post h3 a:focus,
	.widget_latest_post a:hover time,
	.widget_latest_post a:focus time,
	.widget_featured_post h3 a:hover,
	.widget_featured_post h3 a:focus,
	.widget_featured_post a:hover time,
	.widget_featured_post a:focus time,
	.widget_popular_post a time,
	.widget_popular_post time,
	.widget_latest_post a time,
	.widget_latest_post time,
	.widget_featured_post a time,
	.widget_featured_post time,
	#secondary a:hover,
	#secondary a:focus,
	ul.post-categories li:after,
	.byline span a:hover,
	.byline span a:focus,
	.posted-on a:hover,
	.posted-on a:focus,
	.comment-meta .url:hover,
	.comment-meta .url:focus,
	.comment-metadata a,
	.comment-metadata a time,
	.comment-metadata a:hover,
	.comment-metadata a:focus,
	.comment-metadata a:hover time,
	.comment-metadata a:focus time,
	.section-subtitle,
	.more-link:hover,
	.more-link:focus,
	.blog-posts .entry-title a:hover,
	.blog-posts .entry-title a:focus,
	#colophon .cat-links a,
	#colophon .footer-widgets-area ul li a:hover,
	#colophon .footer-widgets-area ul li a:focus,
	.main-navigation a:hover,
	.main-navigation ul.nav-menu > li > a:hover,
	.main-navigation ul.nav-menu li.current-menu-item > a,
	.main-navigation ul.nav-menu li:hover > a {
		color: ' . esc_attr( $color_value ) . ';
	}

	.loader-container svg,
	.widget svg,
	.navigation.posts-navigation a:hover svg, 
	.navigation.post-navigation a:hover svg,
	.navigation.posts-navigation a:focus svg, 
	.navigation.post-navigation a:focus svg,
	.search-submit:hover svg, 
	#featured-introduction-section .entry-container .search-submit:hover svg.icon-search {
		fill: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Border Color
	--------------------------------------------------------------*/

	.archive-blog-wrapper article .entry-container a.btn,
	#featured-post article:first-child .entry-container a.btn,
	.pagination .page-numbers.current, .pagination .page-numbers:hover, .pagination .page-numbers:focus {
		border-color: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Responsive Color
	--------------------------------------------------------------*/
	@media screen and (min-width: 1024px) {
		#secondary-navigation .main-navigation ul.nav-menu > li.current-menu-item > a,
		#secondary-navigation .main-navigation ul.nav-menu > li > a:hover,
		#secondary-navigation .main-navigation ul.nav-menu > li:hover > a {
			color: ' . esc_attr( $color_value ) . ';
		}
		#secondary-navigation .main-navigation ul.nav-menu > li.current-menu-item > a svg,
		#secondary-navigation .main-navigation ul.nav-menu > li > a:hover svg,
		#secondary-navigation .main-navigation ul.nav-menu > li:hover > a svg {
			fill: ' . esc_attr( $color_value ) . ';
		}
		#top-navigation .main-navigation ul.nav-menu > li.current-menu-item > a, 
		#top-navigation .main-navigation ul.nav-menu > li > a:hover, 
		#top-navigation .main-navigation ul.nav-menu > li:hover > a,
		#masthead .main-navigation ul.nav-menu li.current-menu-item > a, 
		#masthead .main-navigation ul.nav-menu > li > a:hover, 
		.main-navigation ul.nav-menu li:hover > a  {
			color: #333;
		}
	}


	/*--------------------------------------------------------------
	# Preloader
	--------------------------------------------------------------*/

	@keyframes preloader {
	    0% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	    25% {height:30px;transform:translateY(15px);background: ' . esc_attr( $color_value ) . ';}
	    50% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	    100% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	}';

	/**
	 * Filters Blogged Pro custom colors CSS.
	 *
	 * @since Blogged Pro 1.0.0
	 *
	 * @param string $css        Base theme colors CSS.
	 */
	return apply_filters( 'blogged_pro_custom_colors_css', $css );
}
