<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Blogged Pro
 * @since Blogged Pro 1.0.0
 * @return array An array of default values
 */

function blogged_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$blogged_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#fe463a',
		'colorscheme'					=> 'default',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'blogged-pro' ),

		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'blogged-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'blogged-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'blogged-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage sections sortable
		'sortable' 						=> 'slider,featured_slider,latest_posts,must_read_posts,blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'blogged-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		// Top Nav
		'top_bar_nav_section_enable' 	=> true,
		'nav_search_enable'				=> true,

		/* Front Page */

		// Slider
		'slider_section_enable'				=> true,
		'slider_content_type'				=> 'page',
		'slider_count'						=> 4,
		'slider_autoplay_enable'			=> false,

		//featured slider
		'featured_slider_section_enable'	=> true,
		'featured_slider_count'				=> 8,
		'featured_slider_btn_title'			=> esc_html__( 'Read More', 'blogged-pro' ),
		'featured_slider_autoplay_enable'	=> false,

		//latest Posts
		'latest_posts_section_enable'		=> true,
		'latest_posts_count'				=> 4,
		'latest_posts_title'				=> esc_html__( 'Latest Posts', 'blogged-pro' ),
		'latest_posts_content_type'			=> 'post',
		'latest_posts_column'				=> 4,

		//must_read Posts
		'must_read_posts_section_enable'	=> true,
		'must_read_posts_count'				=> 3,
		'must_read_posts_title'				=> esc_html__( 'Must Read Posts', 'blogged-pro' ),
		'must_read_posts_content_type'		=> 'post',
		'must_read_posts_column'			=> 3,	
		'must_read_posts_btn_title'			=> esc_html__( 'Read More', 'blogged-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 3,
		'blog_title'					=> esc_html__( 'Single Column Posts', 'blogged-pro' ),
		'blog_btn_title'				=> esc_html__( 'Show All', 'blogged-pro' ),

	);

	$output = apply_filters( 'blogged_pro_default_theme_options', $blogged_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}