<?php
/**
 *  Featured Featured Slider Section options
 *
 * @package Theme Palace
 * @subpackage Blogged Pro
 * @since Blogged Pro 1.0.0
 */

// Add Featured Slider section
$wp_customize->add_section( 'blogged_pro_featured_slider_section', array(
	'title'             => esc_html__( 'Featured Slider','blogged-pro' ),
	'description'       => esc_html__( 'Featured Slider Section options.', 'blogged-pro' ),
	'panel'             => 'blogged_pro_front_page_panel',
) );

// Featured Slider content enable control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[featured_slider_section_enable]', array(
	'default'			=> 	$options['featured_slider_section_enable'],
	'sanitize_callback' => 'blogged_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blogged_Pro_Switch_Control( $wp_customize, 'blogged_pro_theme_options[featured_slider_section_enable]', array(
	'label'             => esc_html__( 'Featured Slider Section Enable', 'blogged-pro' ),
	'section'           => 'blogged_pro_featured_slider_section',
	'on_off_label' 		=> blogged_pro_switch_options(),
) ) );

// Slider content enable control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[featured_slider_autoplay_enable]', array(
	'default'			=> 	$options['featured_slider_autoplay_enable'],
	'sanitize_callback' => 'blogged_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blogged_Pro_Switch_Control( $wp_customize, 'blogged_pro_theme_options[featured_slider_autoplay_enable]', array(
	'label'             => esc_html__( 'Slider Autoplay Enable', 'blogged-pro' ),
	'section'           => 'blogged_pro_featured_slider_section',
	'active_callback'   => 'blogged_pro_is_featured_slider_section_enable',
	'on_off_label' 		=> blogged_pro_switch_options(),
) ) );

// Featured Slider number control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[featured_slider_count]', array(
	'default'          	=> $options['featured_slider_count'],
	'sanitize_callback' => 'blogged_pro_sanitize_number_range',
	'validate_callback' => 'blogged_pro_validate_featured_slider_count',
) );

$wp_customize->add_control( 'blogged_pro_theme_options[featured_slider_count]', array(
	'label'             => esc_html__( 'Number of Featured Posts', 'blogged-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 16.', 'blogged-pro' ),
	'section'           => 'blogged_pro_featured_slider_section',
	'active_callback'   => 'blogged_pro_is_featured_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 16,
		'style' => 'width: 100px;'
		),
) );

// featured_slider posts drop down chooser control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[featured_slider_categories]', array(
	'sanitize_callback' => 'blogged_pro_sanitize_category_list',
) );

$wp_customize->add_control( new Blogged_Pro_Dropdown_Multiple_Chooser( $wp_customize, 'blogged_pro_theme_options[featured_slider_categories]', array(
	'label'             => esc_html__( 'Select Multiple Categories', 'blogged-pro' ),
	'type'           	=> 'dropdown_multiple_chooser',
	'choices'			=> 	blogged_pro_category_choices(),
	'section'           => 'blogged_pro_featured_slider_section',
	'active_callback'	=> 'blogged_pro_is_featured_slider_section_enable',
) ) );

// featured_slider btn title setting and control
$wp_customize->add_setting( 'blogged_pro_theme_options[featured_slider_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_slider_btn_title'],
) );

$wp_customize->add_control( 'blogged_pro_theme_options[featured_slider_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'blogged-pro' ),
	'section'        	=> 'blogged_pro_featured_slider_section',
	'active_callback' 	=> 'blogged_pro_is_featured_slider_section_enable',
	'type'				=> 'text',
) );
