<?php
/**
 * Latest Posts Section options
 *
 * @package Theme Palace
 * @subpackage Blogged Pro
 * @since Blogged Pro 1.0.0
 */

// Add Latest Posts section
$wp_customize->add_section( 'blogged_pro_latest_posts_section', array(
	'title'             => esc_html__( 'Latest Posts','blogged-pro' ),
	'description'       => esc_html__( 'Latest Posts Section options.', 'blogged-pro' ),
	'panel'             => 'blogged_pro_front_page_panel',
) );

// Latest Posts content enable control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[latest_posts_section_enable]', array(
	'default'			=> 	$options['latest_posts_section_enable'],
	'sanitize_callback' => 'blogged_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blogged_Pro_Switch_Control( $wp_customize, 'blogged_pro_theme_options[latest_posts_section_enable]', array(
	'label'             => esc_html__( 'Latest Posts Section Enable', 'blogged-pro' ),
	'section'           => 'blogged_pro_latest_posts_section',
	'on_off_label' 		=> blogged_pro_switch_options(),
) ) );

// latest_posts title setting and control
$wp_customize->add_setting( 'blogged_pro_theme_options[latest_posts_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['latest_posts_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blogged_pro_theme_options[latest_posts_title]', array(
	'label'           	=> esc_html__( 'Title', 'blogged-pro' ),
	'section'        	=> 'blogged_pro_latest_posts_section',
	'active_callback' 	=> 'blogged_pro_is_latest_posts_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blogged_pro_theme_options[latest_posts_title]', array(
		'selector'            => '#latest-post .section-header h2.section-title',
		'settings'            => 'blogged_pro_theme_options[latest_posts_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'blogged_pro_latest_posts_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[latest_posts_count]', array(
	'default'          	=> $options['latest_posts_count'],
	'sanitize_callback' => 'blogged_pro_sanitize_number_range',
	'validate_callback' => 'blogged_pro_validate_latest_posts_count',
) );

$wp_customize->add_control( 'blogged_pro_theme_options[latest_posts_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'blogged-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'blogged-pro' ),
	'section'           => 'blogged_pro_latest_posts_section',
	'active_callback'   => 'blogged_pro_is_latest_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Latest Posts column control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[latest_posts_column]', array(
	'default'          	=> $options['latest_posts_column'],
	'sanitize_callback' => 'blogged_pro_sanitize_select',
) );

$wp_customize->add_control( 'blogged_pro_theme_options[latest_posts_column]', array(
	'label'             => esc_html__( 'Column Number', 'blogged-pro' ),
	'section'           => 'blogged_pro_latest_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'blogged_pro_is_latest_posts_section_enable',
	'choices'			=> array( 
		2 		=> esc_html__( 'Two Column', 'blogged-pro' ),
		3 		=> esc_html__( 'Three Column', 'blogged-pro' ),
		4 		=> esc_html__( 'Four Column', 'blogged-pro' ),
	),
) );

// Latest Posts content type control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[latest_posts_content_type]', array(
	'default'          	=> $options['latest_posts_content_type'],
	'sanitize_callback' => 'blogged_pro_sanitize_select',
) );

$wp_customize->add_control( 'blogged_pro_theme_options[latest_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'blogged-pro' ),
	'section'           => 'blogged_pro_latest_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'blogged_pro_is_latest_posts_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'blogged-pro' ),
		'post' 		=> esc_html__( 'Post', 'blogged-pro' ),
		'category' 	=> esc_html__( 'Category', 'blogged-pro' ),
	),
) );

for ( $i = 1; $i <= $options['latest_posts_count']; $i++ ) :
	// author collection pages drop down chooser control and setting
	$wp_customize->add_setting( 'blogged_pro_theme_options[latest_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'blogged_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Blogged_Pro_Dropdown_Chooser( $wp_customize, 'blogged_pro_theme_options[latest_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'blogged-pro' ), $i ),
		'section'           => 'blogged_pro_latest_posts_section',
		'choices'			=> blogged_pro_page_choices(),
		'active_callback'	=> 'blogged_pro_is_latest_posts_section_content_page_enable',
	) ) );

	// author collection posts drop down chooser control and setting
	$wp_customize->add_setting( 'blogged_pro_theme_options[latest_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'blogged_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Blogged_Pro_Dropdown_Chooser( $wp_customize, 'blogged_pro_theme_options[latest_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'blogged-pro' ), $i ),
		'section'           => 'blogged_pro_latest_posts_section',
		'choices'			=> blogged_pro_post_choices(),
		'active_callback'	=> 'blogged_pro_is_latest_posts_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'blogged_pro_theme_options[latest_posts_content_category]', array(
	'sanitize_callback' => 'blogged_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Blogged_Pro_Dropdown_Taxonomies_Control( $wp_customize,'blogged_pro_theme_options[latest_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'blogged-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'blogged-pro' ),
	'section'           => 'blogged_pro_latest_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'blogged_pro_is_latest_posts_section_content_category_enable'
) ) );
