<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Blogged Pro
 * @since Blogged Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'blogged_pro_slider_section', array(
	'title'             => esc_html__( 'Slider','blogged-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'blogged-pro' ),
	'panel'             => 'blogged_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'blogged_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blogged_Pro_Switch_Control( $wp_customize, 'blogged_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'blogged-pro' ),
	'section'           => 'blogged_pro_slider_section',
	'on_off_label' 		=> blogged_pro_switch_options(),
) ) );

// Slider content enable control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[slider_autoplay_enable]', array(
	'default'			=> 	$options['slider_autoplay_enable'],
	'sanitize_callback' => 'blogged_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blogged_Pro_Switch_Control( $wp_customize, 'blogged_pro_theme_options[slider_autoplay_enable]', array(
	'label'             => esc_html__( 'Slider Autoplay Enable', 'blogged-pro' ),
	'section'           => 'blogged_pro_slider_section',
	'active_callback'   => 'blogged_pro_is_slider_section_enable',
	'on_off_label' 		=> blogged_pro_switch_options(),
) ) );

// Slider number control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'blogged_pro_sanitize_number_range',
	'validate_callback' => 'blogged_pro_validate_slider_count',
) );

$wp_customize->add_control( 'blogged_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Featured', 'blogged-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'blogged-pro' ),
	'section'           => 'blogged_pro_slider_section',
	'active_callback'   => 'blogged_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'blogged_pro_sanitize_select',
) );

$wp_customize->add_control( 'blogged_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'blogged-pro' ),
	'section'           => 'blogged_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'blogged_pro_is_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'blogged-pro' ),
		'post' 		=> esc_html__( 'Post', 'blogged-pro' ),
		'category' 	=> esc_html__( 'Category', 'blogged-pro' ),
	),
) );


for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'blogged_pro_theme_options[slider_content_page_'. $i .']', array(
		'sanitize_callback' => 'blogged_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Blogged_Pro_Dropdown_Chooser( $wp_customize, 'blogged_pro_theme_options[slider_content_page_'. $i .']', array(
		'label'             => esc_html__( 'Select Page', 'blogged-pro' ),
		'section'           => 'blogged_pro_slider_section',
		'choices'			=> blogged_pro_page_choices(),
		'active_callback'	=> 'blogged_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'blogged_pro_theme_options[slider_content_post_'. $i .']', array(
		'sanitize_callback' => 'blogged_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Blogged_Pro_Dropdown_Chooser( $wp_customize, 'blogged_pro_theme_options[slider_content_post_'. $i .']', array(
		'label'             => esc_html__( 'Select Post', 'blogged-pro' ),
		'section'           => 'blogged_pro_slider_section',
		'choices'			=> blogged_pro_post_choices(),
		'active_callback'	=> 'blogged_pro_is_slider_section_content_post_enable',
	) ) );

endfor;

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'blogged_pro_theme_options[slider_category]', array(
	'sanitize_callback' => 'blogged_pro_sanitize_single_category',
) );

$wp_customize->add_control( new Blogged_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'blogged_pro_theme_options[slider_category]', array(
	'label'             => esc_html__( 'Select Categories', 'blogged-pro' ),
	'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'blogged-pro' ),
	'type'           	=> 'dropdown-taxonomies',
	'section'           => 'blogged_pro_slider_section',
	'active_callback'	=> 'blogged_pro_is_slider_section_content_category_enable',
) ) ); 
