<?php
/**
 * Must Read Posts section
 *
 * This is the template for the content of must_read_posts section
 *
 * @package Theme Palace
 * @subpackage Blogged Pro
 * @since Blogged Pro 1.0.0
 */
if ( ! function_exists( 'blogged_pro_add_must_read_posts_section' ) ) :
    /**
    * Add must_read_posts section
    *
    *@since Blogged Pro 1.0.0
    */
    function blogged_pro_add_must_read_posts_section() {
        $options = blogged_pro_get_theme_options();
        // Check if must_read_posts is enabled on frontpage
        $must_read_posts_enable = apply_filters( 'blogged_pro_section_status', true, 'must_read_posts_section_enable' );

        if ( true !== $must_read_posts_enable ) {
            return false;
        }
        // Get must_read_posts section details
        $section_details = array();
        $section_details = apply_filters( 'blogged_pro_filter_must_read_posts_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render must_read_posts section now.
        blogged_pro_render_must_read_posts_section( $section_details );
    }
endif;

if ( ! function_exists( 'blogged_pro_get_must_read_posts_section_details' ) ) :
    /**
    * must_read_posts section details.
    *
    * @since Blogged Pro 1.0.0
    * @param array $input must_read_posts section details.
    */
    function blogged_pro_get_must_read_posts_section_details( $input ) {
        $options = blogged_pro_get_theme_options();

        // Content type.
        $must_read_posts_content_type  = $options['must_read_posts_content_type'];
        $must_read_posts_count = ! empty( $options['must_read_posts_count'] ) ? $options['must_read_posts_count'] : 4;

        
        $content = array();
        switch ( $must_read_posts_content_type ) {
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $must_read_posts_count; $i++ ) {
                    if ( ! empty( $options['must_read_posts_content_page_' . $i] ) )
                        $page_ids[] = $options['must_read_posts_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $must_read_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $must_read_posts_count; $i++ ) {
                    if ( ! empty( $options['must_read_posts_content_post_' . $i] ) )
                        $post_ids[] = $options['must_read_posts_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $must_read_posts_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['must_read_posts_content_category'] ) ? $options['must_read_posts_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $must_read_posts_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = blogged_pro_trim_content( 15 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// must_read_posts section content details.
add_filter( 'blogged_pro_filter_must_read_posts_section_details', 'blogged_pro_get_must_read_posts_section_details' );


if ( ! function_exists( 'blogged_pro_render_must_read_posts_section' ) ) :
  /**
   * Start must_read_posts section
   *
   * @return string must_read_posts content
   * @since Blogged Pro 1.0.0
   *
   */
   function blogged_pro_render_must_read_posts_section( $content_details = array() ) {
        $options = blogged_pro_get_theme_options();
        $must_read_posts_content_type  = $options['must_read_posts_content_type'];
        $column = ! empty( $options['must_read_posts_column'] ) ? $options['must_read_posts_column'] : 3 ;
        $read_more = ! empty( $options['must_read_posts_btn_title'] ) ? $options['must_read_posts_btn_title'] : esc_html__( 'Read More', 'blogged-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="must-read" class="col-<?php echo absint($column); ?> page-section no-padding-bottom">
            <?php if ( ! empty( $options['must_read_posts_title'] ) ) : ?>
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['must_read_posts_title'] ); ?></h2>
                </div><!-- .section-header -->
            <?php endif; ?>

             <div class="section-content clear">
             <?php foreach ( $content_details as $content ) : ?>
                <article class="hentry">
                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"></div>
                    <div class="entry-container">
                        <div class="entry-meta">
                            <?php 
                                blogged_pro_posted_on( $content['id'] ); 
                                if ( 'page' !== $must_read_posts_content_type ) : ?>
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->
                            <?php endif; ?>  
                        </div><!-- .entry-meta -->

                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>

                       <div class="entry-content">
                            <p>
                                <?php echo esc_html( $content['excerpt'] ); ?>  
                                <a href="<?php echo esc_url( $content['url'] ); ?>">
                                    <span class="screen-reader-text"><?php echo esc_html( $content['title'] ); ?></span>
                                    <?php echo esc_html( $read_more ); ?>
                                </a>
                            </p>
                        </div>   
                    </div><!-- .entry-container -->
                </article><!-- .hentry -->
                <?php endforeach; ?>
             </div><!-- .section-content -->
        </div><!-- #must-read -->
    <?php
    }    
endif;
 
