<?php
/**
 * Banner section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Blogged Pro
 * @since Blogged Pro 1.0.0
 */
if ( ! function_exists( 'blogged_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Blogged Pro 1.0.0
    */
    function blogged_pro_add_slider_section() {
    	$options = blogged_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'blogged_pro_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'blogged_pro_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        blogged_pro_render_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'blogged_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Blogged Pro 1.0.0
    * @param array $input slider section details.
    */
    function blogged_pro_get_slider_section_details( $input ) {
        $options = blogged_pro_get_theme_options();

        // Content type.
        $slider_content_type  = $options['slider_content_type'];
        $slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 4;
        
        $content = array();
        switch ( $slider_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_category'] ) ? $options['slider_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $slider_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['author']    = blogged_pro_author();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'blogged_pro_filter_slider_section_details', 'blogged_pro_get_slider_section_details' );


if ( ! function_exists( 'blogged_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Blogged Pro 1.0.0
   *
   */
   function blogged_pro_render_slider_section( $content_details = array() ) {
        $options = blogged_pro_get_theme_options();
        $slider_content_type  = $options['slider_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="featured-slider" class="relative modern-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 500, "dots": false, "arrows":true, "autoplay": <?php echo $options['slider_autoplay_enable'] ? 'true': 'false'; ?>, "draggable": true, "fade": false }'>
            <?php 
                $i=1;
                foreach ( $content_details as $content ) : ?>
                    <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');" class="<?php echo ($i==1) ? 'display-block' : 'display-none';?>">
                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-meta">
                                <?php 
                                    echo wp_kses_post( $content['author'] );
                                    blogged_pro_posted_on( $content['id'] ); 
                                    if ( 'page' !== $slider_content_type ) : ?>
                                        <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span><!-- .cat-links -->
                                <?php endif; ?> 

                            </div><!-- .entry-meta -->
                        </div><!-- .entry-container -->
                    </article>
            <?php 
                $i++;
                endforeach; ?>
       </div><!-- #featured-slider -->
    <?php
    }    
endif;